@@ -36,11 +36,6 @@ BookmarksList::BookmarksList(SharedObjects *sharedObjects, QWidget *parent)
         addItem(item);
     }
 
-    // Show the first bookmark's coordinates if we have bookmarks
-    if (! m_bookmarks.isEmpty()) {
-        setCurrentItem(0);
-    }
-
     connect(this, &QListWidget::itemClicked, this, &BookmarksList::centerBookmark);
     connect(this, &QListWidget::currentItemChanged, this, &BookmarksList::itemHighlighted);
 
@@ -196,7 +191,7 @@ void BookmarksList::renameBookmark()
 {
     const auto currentLabel = m_contextMenuItem->text();
     auto [ newLabel, okay ] = getString(i18n("Rename Bookmark"),
-                                        i18n("New label for the new bookmark:"), currentLabel);
+                                        i18n("New label for the bookmark \"%1\":", currentLabel));
     if (! okay || newLabel == currentLabel) {
         return;
     }
