@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2020 Tobias Leupold <tl at stonemx dot de>
+// SPDX-FileCopyrightText: 2020-2024 Tobias Leupold <tl at stonemx dot de>
 //
 // SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -15,6 +15,7 @@
 // Qt classes
 class QLineEdit;
 class QDoubleSpinBox;
+class QComboBox;
 
 class CoordinatesDialog : public QDialog
 {
@@ -26,7 +27,8 @@ public:
         EditCoordinates
     };
 
-    explicit CoordinatesDialog(Mode mode, bool hideAlt,
+    explicit CoordinatesDialog(Mode mode, bool hideAlt, bool latBeforeLon,
+                               KGeoTag::CoordinatesFlavor flavor,
                                const Coordinates &coordinates = Coordinates(),
                                const QString &target = QString());
     QString label() const;
@@ -36,9 +38,19 @@ public:
     Coordinates coordinates() const;
 
 private: // Variables
+    KGeoTag::CoordinatesFlavor m_flavor;
     QLineEdit *m_label;
-    QDoubleSpinBox *m_lon;
-    QDoubleSpinBox *m_lat;
+
+    QDoubleSpinBox *m_lonDeg;
+    QDoubleSpinBox *m_lonMin;
+    QDoubleSpinBox *m_lonSec;
+    QComboBox *m_lonDirection;
+
+    QDoubleSpinBox *m_latDeg;
+    QDoubleSpinBox *m_latMin;
+    QDoubleSpinBox *m_latSec;
+    QComboBox *m_latDirection;
+
     QDoubleSpinBox *m_alt;
 
 };
