@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2020-2022 Tobias Leupold <tl at stonemx dot de>
+// SPDX-FileCopyrightText: 2020-2024 Tobias Leupold <tl at stonemx dot de>
 //
 // SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -20,6 +20,21 @@ static const QLatin1String s_windowState("windowState");
 static const QLatin1String s_lastOpenPath("lastOpenPath");
 static const QLatin1String s_splitImagesList("splitImagesList");
 
+// Coordinates
+static const QLatin1String s_coordinates("coordinates");
+static const QLatin1String s_latBeforeLon("latBeforeLon");
+static const QLatin1String s_coordinatesFlavor("flavor");
+static const QHash<KGeoTag::CoordinatesFlavor, QString> s_flavorEnumToString {
+    { KGeoTag::DecimalDegrees,               QStringLiteral("DecimalDegrees") },
+    { KGeoTag::DegreesDecimalMinutes,        QStringLiteral("DegreesDecimalMinutes") },
+    { KGeoTag::DegreesMinutesDecimalSeconds, QStringLiteral("DegreesMinutesDecimalSeconds") }
+};
+static const QHash<QString, KGeoTag::CoordinatesFlavor> s_flavorStringToEnum {
+    { QStringLiteral("DecimalDegrees"),               KGeoTag::DecimalDegrees },
+    { QStringLiteral("DegreesDecimalMinutes"),        KGeoTag::DegreesDecimalMinutes },
+    { QStringLiteral("DegreesMinutesDecimalSeconds"), KGeoTag::DegreesMinutesDecimalSeconds }
+};
+
 // Map
 static const QLatin1String s_map("map");
 static const QLatin1String s_showCrosshairs("showCrosshairs");
@@ -78,6 +93,8 @@ static const QVector<QString> s_defaultMatchingModeString {
 };
 static const QString &s_defaultMatchingModePreset = s_defaultMatchingModeString.at(0);
 
+static const QLatin1String s_selectNextUntagged("selectNextUntagged");
+
 // Elevation lookup
 static const QLatin1String s_elevationLookup("elevationLookup");
 static const QLatin1String s_lookupElevationAutomatically("lookupElevationAutomatically");
@@ -123,23 +140,34 @@ static const QString s_bookmarksDataAlt = QStringLiteral("alt");
 Settings::Settings(QObject *parent) : QObject(parent)
 {
     m_config = KSharedConfig::openConfig();
+
+    // Initialize the "lat before lon" bool
+    auto group = m_config->group(s_coordinates);
+    m_latBeforeLon = group.readEntry(s_latBeforeLon, false);
+
+    // Initialize the coordinates flavor
+    const auto flavor = group.readEntry(s_coordinatesFlavor,
+                                        s_flavorEnumToString.value(KGeoTag::DecimalDegrees));
+    m_coordinatesFlavor = s_flavorStringToEnum.contains(flavor)
+                              ? s_flavorStringToEnum.value(flavor)
+                              : KGeoTag::DecimalDegrees;
 }
 
-// Main
-
-void Settings::saveMainWindowState(const QByteArray &data)
-{
-    auto group = m_config->group(s_main);
-    group.writeEntry(s_windowState, data);
-    group.sync();
-}
+// KMainWindow settings
 
 QByteArray Settings::mainWindowState() const
 {
-    auto group = m_config->group(s_main);
-    return group.readEntry(s_windowState, QByteArray());
+    // NOTE: Most probably, when porting this to KF6, we will need to read
+    // KSharedConfig::openStateConfig() to get this, as apparently, KF6 doesn't store the state
+    // information in ~/.config/...rc, but in an extra "state" rc file.
+
+    auto group = m_config->group(QStringLiteral("MainWindow"));
+    const auto state = group.readEntry(QStringLiteral("State"), QString());
+    return QByteArray::fromBase64(state.toUtf8());
 }
 
+// Main
+
 void Settings::saveLastOpenPath(const QString &path)
 {
     auto group = m_config->group(s_main);
@@ -510,3 +538,42 @@ KGeoTag::SearchType Settings::defaultMatchingMode() const
         return KGeoTag::CombinedMatchSearch;
     }
 }
+
+void Settings::saveSelectNextUntagged(bool state)
+{
+    auto group = m_config->group(s_assignment);
+    group.writeEntry(s_selectNextUntagged, state);
+    group.sync();
+}
+
+bool Settings::selectNextUntagged() const
+{
+    auto group = m_config->group(s_assignment);
+    return group.readEntry(s_selectNextUntagged, true);
+}
+
+void Settings::saveLatBeforeLon(bool state)
+{
+    m_latBeforeLon = state;
+    auto group = m_config->group(s_coordinates);
+    group.writeEntry(s_latBeforeLon, state);
+    group.sync();
+}
+
+bool Settings::latBeforeLon() const
+{
+    return m_latBeforeLon;
+}
+
+void Settings::saveCoordinatesFlavor(KGeoTag::CoordinatesFlavor flavor)
+{
+    m_coordinatesFlavor = flavor;
+    auto group = m_config->group(s_coordinates);
+    group.writeEntry(s_coordinatesFlavor, s_flavorEnumToString.value(flavor));
+    group.sync();
+}
+
+KGeoTag::CoordinatesFlavor Settings::coordinatesFlavor() const
+{
+    return m_coordinatesFlavor;
+}
