@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2020-2022 Tobias Leupold <tl at stonemx dot de>
+// SPDX-FileCopyrightText: 2020-2024 Tobias Leupold <tl at stonemx dot de>
 //
 // SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -25,9 +25,11 @@
 #include <QScrollBar>
 #include <QMessageBox>
 #include <QHBoxLayout>
+#include <QApplication>
 
 SettingsDialog::SettingsDialog(Settings *settings, QWidget *parent)
-    : QDialog(parent), m_settings(settings)
+    : QDialog(parent),
+      m_settings(settings)
 {
     setAttribute(Qt::WA_DeleteOnClose, true);
     setWindowTitle(i18n("KGeoTag: Settings"));
@@ -52,6 +54,45 @@ SettingsDialog::SettingsDialog(Settings *settings, QWidget *parent)
 
     auto *layout = new QVBoxLayout(settingsWidget);
 
+    // Coordinates
+
+    auto *coordinatesBox = new QGroupBox(i18n("Coordinates"));
+    layout->addWidget(coordinatesBox);
+
+    auto *coordinatesBoxLayout = new QVBoxLayout(coordinatesBox);
+
+    auto *coordinatesBoxWrapper = new QHBoxLayout;
+    coordinatesBoxLayout->addLayout(coordinatesBoxWrapper);
+
+    auto *coordinatesSettingsLayout = new QGridLayout;
+    coordinatesBoxWrapper->addLayout(coordinatesSettingsLayout);
+    coordinatesBoxWrapper->addStretch();
+
+    coordinatesSettingsLayout->addWidget(new QLabel(i18n("Coordinates order:")), 0, 0);
+    m_coordinatesOrder = new QComboBox;
+    m_coordinatesOrder->addItem(i18n("Longitude, latitude"));
+    m_coordinatesOrder->addItem(i18n("Latitude, longitude"));
+    m_coordinatesOrder->setCurrentIndex(m_settings->latBeforeLon());
+    coordinatesSettingsLayout->addWidget(m_coordinatesOrder, 0, 1);
+
+    coordinatesSettingsLayout->addWidget(new QLabel(i18n("Coordinates flavor:")), 1, 0);
+    m_coordinatesFlavor = new QComboBox;
+    m_coordinatesFlavor->addItem(i18n("Decimal degrees"),
+                                 static_cast<int>(KGeoTag::DecimalDegrees));
+    m_coordinatesFlavor->addItem(i18n("Degrees, decimal minutes"),
+                                 static_cast<int>(KGeoTag::DegreesDecimalMinutes));
+    m_coordinatesFlavor->addItem(i18n("Degrees, minutes, decimal seconds"),
+                                 static_cast<int>(KGeoTag::DegreesMinutesDecimalSeconds));
+    m_coordinatesFlavor->setCurrentIndex(
+        m_coordinatesFlavor->findData(static_cast<int>(m_settings->coordinatesFlavor())));
+    coordinatesSettingsLayout->addWidget(m_coordinatesFlavor, 1, 1);
+
+    auto *coordinatesSettingsLabel = new QLabel(i18n(
+        "Changes to the coordinates formatting take effect as soon as the respective coordinates "
+        "display is updated the next time. Restart KGeoTag to update everything at once."));
+    coordinatesSettingsLabel->setWordWrap(true);
+    coordinatesBoxLayout->addWidget(coordinatesSettingsLabel);
+
     // Image lists
 
     auto *listsBox = new QGroupBox(i18n("Image lists"));
@@ -60,13 +101,13 @@ SettingsDialog::SettingsDialog(Settings *settings, QWidget *parent)
     auto *listsBoxLayout = new QVBoxLayout(listsBox);
 
     auto *listsModeLabel = new QLabel(i18n(
-        "<p>Loaded images can either be listed in two different lists (one for all images without "
-        "and one for images with coordinates), or using a combined consecutive list for all images."
-        "</p>"
-        "<p>Use the following images list(s) mode:</p>"));
+        "Loaded images can either be listed in two different lists (one for all images without and "
+        "one for images with coordinates), or using a combined consecutive list for all images."));
     listsModeLabel->setWordWrap(true);
     listsBoxLayout->addWidget(listsModeLabel);
 
+    listsBoxLayout->addWidget(new QLabel(i18n("Use the following images list(s) mode:")));
+
     m_imageListsMode = new QComboBox;
     m_imageListsMode->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::MinimumExpanding);
 
@@ -74,6 +115,7 @@ SettingsDialog::SettingsDialog(Settings *settings, QWidget *parent)
     m_imageListsMode->addItem(i18n("One combined list for all images"));
 
     m_imageListsMode->setCurrentIndex(m_settings->splitImagesList() ? 0 : 1);
+    m_originalSplitImagesListValue = m_imageListsMode->currentIndex() == 0;
 
     listsBoxLayout->addWidget(m_imageListsMode);
 
@@ -84,10 +126,8 @@ SettingsDialog::SettingsDialog(Settings *settings, QWidget *parent)
 
     auto *searchMatchesBoxLayout = new QVBoxLayout(searchMatchesBox);
 
-    auto *matchModeLabel = new QLabel(i18n("Search type for the main menu \"Assign images to GPS "
-                                           "data\" entry"));
-    matchModeLabel->setWordWrap(true);
-    searchMatchesBoxLayout->addWidget(matchModeLabel);
+    searchMatchesBoxLayout->addWidget(new QLabel(
+        i18n("Search type for \"Correlate images with GPS data (search matches)\":")));
 
     m_automaticMatchingMode = new QComboBox;
     m_automaticMatchingMode->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::MinimumExpanding);
@@ -120,7 +160,7 @@ SettingsDialog::SettingsDialog(Settings *settings, QWidget *parent)
     sizesLayoutWrapper->addLayout(sizesLayout);
     row = -1;
 
-    sizesLayout->addWidget(new QLabel(i18n("Thumbnail size:")), ++row, 0);
+    sizesLayout->addWidget(new QLabel(i18n("Image list thumbnail size:")), ++row, 0);
     m_thumbnailSize = new QSpinBox;
     m_thumbnailSize->setMinimum(16);
     m_thumbnailSize->setMaximum(512);
@@ -129,7 +169,7 @@ SettingsDialog::SettingsDialog(Settings *settings, QWidget *parent)
     sizesLayout->addWidget(m_thumbnailSize, row, 1);
     sizesLayout->addWidget(new QLabel(i18n("px")), row, 2);
 
-    sizesLayout->addWidget(new QLabel(i18n("Preview size:")), ++row, 0);
+    sizesLayout->addWidget(new QLabel(i18n("Preview image size:")), ++row, 0);
     m_previewSize = new QSpinBox;
     m_previewSize->setMinimum(100);
     m_previewSize->setMaximum(1920);
@@ -287,7 +327,7 @@ SettingsDialog::SettingsDialog(Settings *settings, QWidget *parent)
     label->setIndent(30);
     saveBoxLayout->addWidget(label);
 
-    m_createBackups = new QCheckBox(i18n("Create a backups before altering a file"));
+    m_createBackups = new QCheckBox(i18n("Create a backup before altering a file"));
     m_createBackups->setChecked(m_settings->createBackups());
     saveBoxLayout->addWidget(m_createBackups);
 
@@ -295,14 +335,15 @@ SettingsDialog::SettingsDialog(Settings *settings, QWidget *parent)
 
     auto *scrollArea = new QScrollArea;
     scrollArea->setWidgetResizable(true);
-    const int styleAddition = scrollArea->width() - scrollArea->viewport()->width();
     scrollArea->setWidget(settingsWidget);
+    scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     mainLayout->addWidget(scrollArea);
 
-    show();
-    const int widgetWidth = settingsWidget->width() + scrollArea->verticalScrollBar()->width()
-                            + styleAddition;
-    scrollArea->setMinimumWidth(widgetWidth);
+    // Set the exact needed width as a minimum, so that nothing is cut off
+    scrollArea->ensurePolished();
+    scrollArea->setMinimumWidth(settingsWidget->width()
+                                + scrollArea->verticalScrollBar()->width()
+                                + scrollArea->frameWidth() * 2);
 
     // Button box
 
@@ -334,6 +375,10 @@ void SettingsDialog::setTrackColor()
 
 void SettingsDialog::accept()
 {
+    m_settings->saveLatBeforeLon(m_coordinatesOrder->currentIndex());
+    m_settings->saveCoordinatesFlavor(static_cast<KGeoTag::CoordinatesFlavor>(
+        m_coordinatesFlavor->currentData().toInt()));
+
     const auto splitImagesList = m_imageListsMode->currentIndex() == 0;
     m_settings->saveSplitImagesList(splitImagesList);
 
